@@ -41,6 +41,8 @@
 #include <gnome.h>
 #include <libgnomeui/gnome-window-icon.h>
 
+#include <gconf/gconf-client.h>
+
 #include <stdio.h>
 #include <fcntl.h>
 #include <errno.h>
@@ -1264,22 +1266,20 @@ visibility_toggled (GtkWidget *w, gpointer data)
 
 #endif
 
-static GtkWidget*
-xst_tool_create_platform_list (XstTool *tool)
+static void
+xst_tool_create_platform_list (GtkTreeView *list, XstTool *tool)
 {
 	GtkTreeModel *model = GTK_TREE_MODEL (gtk_tree_store_new (PLATFORM_LIST_COL_LAST, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_POINTER));
-	
-	GtkWidget *list;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 	GtkTreeSelection *select;
-	
-	list = gtk_tree_view_new_with_model (model);
+
+	g_return_if_fail (list != NULL);
+	g_return_if_fail (GTK_IS_TREE_VIEW (list));
+
+	gtk_tree_view_set_model (GTK_TREE_VIEW (list), model);
 	g_object_unref (model);
 	
-	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (list), TRUE);
-	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (list), FALSE);
-	
 	/* Insert the pixmaps cell */
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	g_object_set (G_OBJECT (renderer), "xalign", 0.0, NULL);
@@ -1306,16 +1306,12 @@ xst_tool_create_platform_list (XstTool *tool)
 	g_signal_connect (G_OBJECT (select), "changed",
 			  G_CALLBACK (on_platform_list_selection_changed),
 			  (gpointer) tool);
-
-	gtk_widget_show_all (list);
-	return list;
 }
 
 static void
 xst_tool_type_init (XstTool *tool)
 {
 	GladeXML *xml;
-	GtkWidget *sw;
 
 	tool->glade_common_path  = g_strdup_printf ("%s/common.glade", INTERFACES_DIR);
 
@@ -1355,12 +1351,8 @@ xst_tool_type_init (XstTool *tool)
 #endif
 
 	xml = xst_tool_load_glade_common (tool, "platform_dialog");
-	
-	/* We get the scrolled window that will contain the list and embed the GtkTreeView into it */
-	sw = glade_xml_get_widget (xml, "platform_list_holder");
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
-	tool->platform_list = xst_tool_create_platform_list (tool);
-	gtk_container_add (GTK_CONTAINER (sw), tool->platform_list);
+	tool->platform_list = glade_xml_get_widget (xml, "platform_list");
+	xst_tool_create_platform_list (GTK_TREE_VIEW (tool->platform_list), tool);
 
 	tool->platform_dialog    = glade_xml_get_widget (xml, "platform_dialog");
 	tool->platform_ok_button = glade_xml_get_widget (xml, "platform_ok_button");
@@ -1575,58 +1567,39 @@ xst_tool_reset_report_hooks (XstTool *tool)
 		((XstReportHook *) list->data)->invoked = FALSE;
 }
 
-/**
- * xst_fool_the_linker:
- * @void: 
- * 
- * We need to keep the symbol for the create image widget function
- * so that libglade can find it to create the icons.
- **/
-void xst_fool_the_linker (void);
-void
-xst_fool_the_linker (void)
-{
-	xst_ui_image_widget_create (NULL, NULL, NULL, 0, 0);
-}
-
+/* it does authentication, first of all it runs su (just to ensure that it's completely run
+ * when password is sent), then asks for password and sends it to su (if you want to run it
+ * with root privileges)
+ */
 static void
 authenticate (int argc, char *argv[])
 {
-	GtkWidget *error_dialog;
 	gchar *password;
 	gint result;
 
-	for (;;)
-	{
-		result = xst_su_get_password (&password);
+	xst_su_run_term (argc, argv, NULL);
 
-		if (result < 0)
-			exit (0);
-		else if (result == 0)
-			return;
+	result = xst_su_get_password (&password);
 
-		/* If successful, the following never returns */
+	if (result == 1) 
+		xst_su_write_password (password);
+	else if (result == -1)
+		exit (0);
+	else
+		xst_su_clear_term ();
 
-		xst_su_run_with_password (argc, argv, password);
-
-		if (strlen (password))
-			memset (password, 0, strlen (password));
-
-		error_dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
-						       GTK_MESSAGE_ERROR,
-						       GTK_BUTTONS_OK,
-						       _("The password you entered is invalid."));
-
-		gtk_dialog_run (GTK_DIALOG (error_dialog));
-		gtk_widget_destroy (error_dialog);
-	}
+	if (strlen (password) > 0)
+		memset (password, 0, strlen (password));
 }
 
 static void
 try_show_usage_warning (void)
 {
-	gchar *key;
+	gchar *key, *version_key;
 	gboolean value;
+	gchar *version;
+	GConfClient *client;
+	GError *error = NULL;
 	gchar *warning = g_strdup_printf(_("Welcome to the %s prerelease of the "
 		  "GNOME System Tools.\n\n"
 		  "This is still a work in progress, and so it may have serious bugs.\n"
@@ -1635,11 +1608,17 @@ try_show_usage_warning (void)
 		  "You have been warned. Thank you for trying out this prerelease of\n"
 		  "the GNOME System Tools!\n\n"
 		  "--\nThe GNOME System Tools team"), VERSION);
-	key = g_strjoin ("/", XST_CONF_ROOT, "global", "previously-run-" VERSION, NULL);
 
-	value = gnome_config_get_bool (key);
+	client = gconf_client_get_default ();
 
-	if (!value)
+	version_key = g_strjoin ("/", GST_GCONF_ROOT, "global", "last-version", NULL);
+	key = g_strjoin ("/", GST_GCONF_ROOT, "global", "show_warning", NULL);
+
+
+	value = gconf_client_get_bool (client, key, &error);
+	version = gconf_client_get_string (client, version_key, &error);
+
+	if ((value == TRUE) || (strcmp (version, VERSION) != 0))
 	{
 		GtkWidget *dialog, *label, *image, *hbox;
 		GtkWidget *checkbox;
@@ -1668,9 +1647,9 @@ try_show_usage_warning (void)
 		
 		gtk_widget_show_all (dialog);
 		if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
-			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbox))) {
-				gnome_config_set_bool (key, TRUE);
-				gnome_config_sync ();
+			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (checkbox)) == TRUE) {
+				gconf_client_set_bool (client, key, FALSE, &error);
+				gconf_client_set_string (client, version_key, VERSION, &error);
 			}
 		}
 		gtk_widget_hide (dialog);
@@ -1724,7 +1703,6 @@ xst_init (const gchar *app_name, int argc, char *argv [], const poptOption optio
 				      _("GNOME System Tools"),
 				      NULL);
 	
-
 	if (geteuid () == 0) {
 		root_access = ROOT_ACCESS_REAL;
 #ifdef XST_DEBUG
